@@ -15,8 +15,10 @@ pub enum Commands {
         excluded_directories: ExcludedDirectories,
         #[structopt(flatten)]
         excluded_items: ExcludedItems,
-        #[structopt(short, long, parse(try_from_str = parse_minimal_file_size), default_value = "1024", help = "Minimum size in bytes", long_help = "Minimum size of checked files in bytes, assigning bigger value may speed up searching")]
+        #[structopt(short, long, parse(try_from_str = parse_minimal_file_size), default_value = "8192", help = "Minimum size in bytes", long_help = "Minimum size of checked files in bytes, assigning bigger value may speed up searching")]
         minimal_file_size: u64,
+        #[structopt(short = "i", long, parse(try_from_str = parse_maximal_file_size), default_value = "18446744073709551615", help = "Maximum size in bytes", long_help = "Maximum size of checked files in bytes, assigning lower value may speed up searching")]
+        maximal_file_size: u64,
         #[structopt(short = "c", long, parse(try_from_str = parse_minimal_file_size), default_value = "2097152", help = "Minimum cached file size in bytes", long_help = "Minimum size of cached files in bytes, assigning bigger value may speed up will cause that lower amount of files will be cached, but loading of cache will be faster")]
         minimal_cached_file_size: u64,
         #[structopt(flatten)]
@@ -109,7 +111,9 @@ pub enum Commands {
         excluded_directories: ExcludedDirectories,
         #[structopt(short, long, parse(try_from_str = parse_minimal_file_size), default_value = "16384", help = "Minimum size in bytes", long_help = "Minimum size of checked files in bytes, assigning bigger value may speed up searching")]
         minimal_file_size: u64,
-        #[structopt(short, long, default_value = "High", parse(try_from_str = parse_similar_images_similarity), help = "Similairty level (Minimal, VerySmall, Small, Medium, High, Very High)", long_help = "Methods to choose similarity level of images which will be considered as duplicated.")]
+        #[structopt(short = "i", long, parse(try_from_str = parse_maximal_file_size), default_value = "18446744073709551615", help = "Maximum size in bytes", long_help = "Maximum size of checked files in bytes, assigning lower value may speed up searching")]
+        maximal_file_size: u64,
+        #[structopt(short, long, default_value = "High", parse(try_from_str = parse_similar_images_similarity), help = "Similairty level (Minimal, VerySmall, Small, Medium, High, VeryHigh)", long_help = "Methods to choose similarity level of images which will be considered as duplicated.")]
         similarity: Similarity,
         #[structopt(flatten)]
         excluded_items: ExcludedItems,
@@ -134,8 +138,10 @@ pub enum Commands {
         file_to_save: FileToSave,
         #[structopt(flatten)]
         not_recursive: NotRecursive,
-        #[structopt(short, long, parse(try_from_str = parse_minimal_file_size), default_value = "1024", help = "Minimum size in bytes", long_help = "Minimum size of checked files in bytes, assigning bigger value may speed up searching")]
+        #[structopt(short, long, parse(try_from_str = parse_minimal_file_size), default_value = "8192", help = "Minimum size in bytes", long_help = "Minimum size of checked files in bytes, assigning bigger value may speed up searching")]
         minimal_file_size: u64,
+        #[structopt(short = "i", long, parse(try_from_str = parse_maximal_file_size), default_value = "18446744073709551615", help = "Maximum size in bytes", long_help = "Maximum size of checked files in bytes, assigning lower value may speed up searching")]
+        maximal_file_size: u64,
     },
     #[structopt(name = "music", about = "Finds same music by tags", help_message = HELP_MESSAGE, after_help = "EXAMPLE:\n    czkawka music -d /home/rafal -f results.txt")]
     SameMusic {
@@ -153,8 +159,10 @@ pub enum Commands {
         file_to_save: FileToSave,
         #[structopt(flatten)]
         not_recursive: NotRecursive,
-        #[structopt(short, long, parse(try_from_str = parse_minimal_file_size), default_value = "1024", help = "Minimum size in bytes", long_help = "Minimum size of checked files in bytes, assigning bigger value may speed up searching")]
+        #[structopt(short, long, parse(try_from_str = parse_minimal_file_size), default_value = "8192", help = "Minimum size in bytes", long_help = "Minimum size of checked files in bytes, assigning bigger value may speed up searching")]
         minimal_file_size: u64,
+        #[structopt(short = "i", long, parse(try_from_str = parse_maximal_file_size), default_value = "18446744073709551615", help = "Maximum size in bytes", long_help = "Maximum size of checked files in bytes, assigning lower value may speed up searching")]
+        maximal_file_size: u64,
     },
     #[structopt(name = "symlinks", about = "Finds invalid symlinks", help_message = HELP_MESSAGE, after_help = "EXAMPLE:\n    czkawka symlinks -d /home/kicikici/ /home/szczek -e /home/kicikici/jestempsem -x jpg -f results.txt")]
     InvalidSymlinks {
@@ -286,14 +294,15 @@ fn parse_delete_method(src: &str) -> Result<DeleteMethod, &'static str> {
     }
 }
 
+// TODO For now it looks different
 fn parse_similar_images_similarity(src: &str) -> Result<Similarity, &'static str> {
     match src.to_ascii_lowercase().replace('_', "").as_str() {
-        "minimal" => Ok(Similarity::Minimal),
-        "verysmall" => Ok(Similarity::VerySmall),
-        "small" => Ok(Similarity::Small),
-        "medium" => Ok(Similarity::Medium),
-        "high" => Ok(Similarity::High),
-        "veryhigh" => Ok(Similarity::VeryHigh),
+        "minimal" => Ok(Similarity::Similar(12)),
+        "verysmall" => Ok(Similarity::Similar(8)),
+        "small" => Ok(Similarity::Similar(5)),
+        "medium" => Ok(Similarity::Similar(3)),
+        "high" => Ok(Similarity::Similar(1)),
+        "veryhigh" => Ok(Similarity::Similar(0)),
         _ => Err("Couldn't parse the delete method (allowed: verysmall, small, medium, high, veryhigh)"),
     }
 }
@@ -311,6 +320,13 @@ fn parse_minimal_file_size(src: &str) -> Result<u64, String> {
     }
 }
 
+fn parse_maximal_file_size(src: &str) -> Result<u64, String> {
+    match src.parse::<u64>() {
+        Ok(maximal_file_size) => Ok(maximal_file_size),
+        Err(e) => Err(e.to_string()),
+    }
+}
+
 fn parse_music_duplicate_type(src: &str) -> Result<MusicSimilarity, String> {
     if src.is_empty() {
         return Ok(MusicSimilarity::NONE);
